==> square_database_structure-1.0.2.tar.gz: square_database_structure-1.0.2/square_database_structure/square/authentication/tables.py <==
from sqlalchemy import (
    Column,
    Integer,
    MetaData,
    DateTime,
    text,
    String,
    ForeignKey,
)
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import declarative_base

from square_database_structure.square.authentication import global_string_schema_name
from square_database_structure.square.public.tables import App

Base = declarative_base(metadata=MetaData(schema=global_string_schema_name))

data_to_insert = []


class User(Base):
    __tablename__ = "user"

    user_id = Column(
        UUID,
        primary_key=True,
        nullable=False,
        unique=True,
        server_default=text("gen_random_uuid()"),
    )


class UserCredential(Base):
    __tablename__ = "user_credential"

    user_credential_id = Column(
        Integer, primary_key=True, nullable=False, unique=True, autoincrement=True
    )
    user_id = Column(
        UUID,
        ForeignKey(User.user_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
        unique=True,
    )
    user_credential_username = Column(String, nullable=False, unique=True, index=True)
    user_credential_hashed_password = Column(String, nullable=False)


class UserApp(Base):
    __tablename__ = "user_app"

    user_app_id = Column(
        Integer, primary_key=True, unique=True, nullable=False, autoincrement=True
    )
    user_id = Column(
        UUID,
        ForeignKey(User.user_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
    )
    app_id = Column(
        Integer,
        ForeignKey(App.app_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
    )


class UserSession(Base):
    __tablename__ = "user_session"

    user_session_id = Column(
        Integer, primary_key=True, unique=True, nullable=False, autoincrement=True
    )
    user_app_id = Column(
        Integer,
        ForeignKey(UserApp.user_app_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
    )
    user_session_refresh_token = Column(
        String,
        nullable=False,
        unique=True,
    )
    user_session_expiry_time = Column(DateTime(timezone=True), nullable=False)

==> square_database_structure-2.5.1.tar.gz: square_database_structure-2.5.1/square_database_structure/square/authentication/tables.py <==
from sqlalchemy import (
    Column,
    Integer,
    MetaData,
    DateTime,
    text,
    String,
    ForeignKey,
    Enum,
)
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import declarative_base

from square_database_structure.square.authentication import global_string_schema_name
from square_database_structure.square.authentication.enums import UserStatusEnum
from square_database_structure.square.file_storage.tables import File
from square_database_structure.square.public.tables import App

Base = declarative_base(metadata=MetaData(schema=global_string_schema_name))


class User(Base):
    __tablename__ = "user"

    user_id = Column(
        UUID,
        primary_key=True,
        nullable=False,
        unique=True,
        server_default=text("gen_random_uuid()"),
    )
    user_status = Column(
        Enum(UserStatusEnum, schema=global_string_schema_name),
        nullable=False,
        server_default=UserStatusEnum.ACTIVE.value,
    )


class UserCredential(Base):
    __tablename__ = "user_credential"

    user_credential_id = Column(
        Integer, primary_key=True, nullable=False, unique=True, autoincrement=True
    )
    user_id = Column(
        UUID,
        ForeignKey(User.user_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
        unique=True,
    )
    user_credential_hashed_password = Column(String, nullable=False)


class UserApp(Base):
    __tablename__ = "user_app"

    user_id = Column(
        UUID,
        ForeignKey(User.user_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
        primary_key=True,
    )
    app_id = Column(
        Integer,
        ForeignKey(App.app_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
        primary_key=True,
    )


class UserSession(Base):
    __tablename__ = "user_session"

    user_session_id = Column(
        Integer, primary_key=True, unique=True, nullable=False, autoincrement=True
    )
    user_id = Column(
        UUID,
        ForeignKey(User.user_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
    )
    app_id = Column(
        Integer,
        ForeignKey(App.app_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
    )
    user_session_refresh_token = Column(
        String,
        nullable=False,
        unique=True,
    )
    user_session_expiry_time = Column(DateTime(timezone=True), nullable=False)


class UserProfile(Base):
    __tablename__ = "user_profile"

    user_profile_id = Column(
        Integer, primary_key=True, unique=True, nullable=False, autoincrement=True
    )
    user_id = Column(
        UUID,
        ForeignKey(User.user_id, ondelete="CASCADE", onupdate="CASCADE"),
        nullable=False,
        unique=True,
    )
    user_profile_photo_storage_token = Column(
        String,
        ForeignKey(File.file_storage_token, ondelete="RESTRICT", onupdate="CASCADE"),
        nullable=True,
        unique=True,
        default=None,
    )
    user_profile_email = Column(
        String,
        nullable=True,
        unique=True,
        default=None,
    )
    user_profile_phone_number = Column(
        String,
        nullable=True,
        unique=True,
        default=None,
    )
    user_profile_first_name = Column(
        String,
        nullable=True,
        default=None,
    )
    user_profile_last_name = Column(
        String,
        nullable=True,
        default=None,
    )
    user_profile_username = Column(String, nullable=False, unique=True, index=True)
